==> ejc-zjkjcost-impl-3.0.0-20221103.104551-84-sources.jar: com/ejianc/business/zjkjcost/manage/bean/ReviewEntity.java <==
package com.ejianc.business.zjkjcost.manage.bean;

import java.util.Date;
import java.math.*;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 项目目标管理责任书评审表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_manage_review")
public class ReviewEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="book_id")
    private Long bookId; // 责任书id
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目部id
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级组织Id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部上级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="built_area")
    private String builtArea; // 建筑面积
    @TableField(value="zb_contract_mny")
    private BigDecimal zbContractMny; // 合同额
    @TableField(value="zs_contract_mny")
    private BigDecimal zsContractMny; // 其中自行施工额
    @TableField(value="start_date")
    private Date startDate; // 合同开工日期
    @TableField(value="end_date")
    private Date endDate; // 合同竣工日期
    @TableField(value="quality_standard")
    private String qualityStandard; // 合同质量目标
    @TableField(value="safety_standard")
    private String safetyStandard; // 合同安全目标
    @TableField(value="xm_review_msg")
    private String xmReviewMsg; // 评审结论-项目部经理
    @TableField(value="sw_review_msg")
    private String swReviewMsg; // 评审结论-商务管理部
    @TableField(value="jz_review_msg")
    private String jzReviewMsg; // 评审结论-建造管理部
    @TableField(value="gc_review_msg")
    private String gcReviewMsg; // 评审结论-工程技术研究中心
    @TableField(value="aq_review_msg")
    private String aqReviewMsg; // 评审结论-安全生产监督管理部
    @TableField(value="cw_review_msg")
    private String cwReviewMsg; // 评审结论- 财务资金部
    @TableField(value="zh_review_msg")
    private String zhReviewMsg; // 评审结论- 综合办公室
    @TableField(value="fg_review_msg")
    private String fgReviewMsg; // 评审结论-分管领导审批
    @TableField(value="zjl_review_msg")
    private String zjlReviewMsg; // 评审结论-总经理
    @TableField(value="dsz_review_msg")
    private String dszReviewMsg; // 评审结论-董事长
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称

    public Long getBookId() {
        return bookId;
    }

    public void setBookId(Long bookId) {
        this.bookId = bookId;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getBuiltArea() {
        return builtArea;
    }

    public void setBuiltArea(String builtArea) {
        this.builtArea = builtArea;
    }
    public BigDecimal getZbContractMny() {
        return zbContractMny;
    }

    public void setZbContractMny(BigDecimal zbContractMny) {
        this.zbContractMny = zbContractMny;
    }
    public BigDecimal getZsContractMny() {
        return zsContractMny;
    }

    public void setZsContractMny(BigDecimal zsContractMny) {
        this.zsContractMny = zsContractMny;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public String getQualityStandard() {
        return qualityStandard;
    }

    public void setQualityStandard(String qualityStandard) {
        this.qualityStandard = qualityStandard;
    }
    public String getSafetyStandard() {
        return safetyStandard;
    }

    public void setSafetyStandard(String safetyStandard) {
        this.safetyStandard = safetyStandard;
    }
    public String getXmReviewMsg() {
        return xmReviewMsg;
    }

    public void setXmReviewMsg(String xmReviewMsg) {
        this.xmReviewMsg = xmReviewMsg;
    }
    public String getSwReviewMsg() {
        return swReviewMsg;
    }

    public void setSwReviewMsg(String swReviewMsg) {
        this.swReviewMsg = swReviewMsg;
    }
    public String getJzReviewMsg() {
        return jzReviewMsg;
    }

    public void setJzReviewMsg(String jzReviewMsg) {
        this.jzReviewMsg = jzReviewMsg;
    }
    public String getGcReviewMsg() {
        return gcReviewMsg;
    }

    public void setGcReviewMsg(String gcReviewMsg) {
        this.gcReviewMsg = gcReviewMsg;
    }
    public String getAqReviewMsg() {
        return aqReviewMsg;
    }

    public void setAqReviewMsg(String aqReviewMsg) {
        this.aqReviewMsg = aqReviewMsg;
    }
    public String getCwReviewMsg() {
        return cwReviewMsg;
    }

    public void setCwReviewMsg(String cwReviewMsg) {
        this.cwReviewMsg = cwReviewMsg;
    }
    public String getZhReviewMsg() {
        return zhReviewMsg;
    }

    public void setZhReviewMsg(String zhReviewMsg) {
        this.zhReviewMsg = zhReviewMsg;
    }
    public String getFgReviewMsg() {
        return fgReviewMsg;
    }

    public void setFgReviewMsg(String fgReviewMsg) {
        this.fgReviewMsg = fgReviewMsg;
    }
    public String getZjlReviewMsg() {
        return zjlReviewMsg;
    }

    public void setZjlReviewMsg(String zjlReviewMsg) {
        this.zjlReviewMsg = zjlReviewMsg;
    }
    public String getDszReviewMsg() {
        return dszReviewMsg;
    }

    public void setDszReviewMsg(String dszReviewMsg) {
        this.dszReviewMsg = dszReviewMsg;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20230512.012712-159-sources.jar: com/ejianc/business/zjkjcost/manage/bean/ReviewEntity.java <==
package com.ejianc.business.zjkjcost.manage.bean;

import java.util.Date;
import java.math.*;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 项目目标管理责任书评审表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_manage_review")
public class ReviewEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="book_id")
    private Long bookId; // 责任书id
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_code")
    private String projectCode; // 项目编码
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 项目部id
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 项目部上级组织Id
    @TableField(value="parent_org_name")
    private String parentOrgName; // 项目部上级组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 项目部上级组织编码
    @TableField(value="built_area")
    private String builtArea; // 建筑面积
    @TableField(value="zb_contract_mny")
    private BigDecimal zbContractMny; // 合同额
    @TableField(value="zs_contract_mny")
    private BigDecimal zsContractMny; // 其中自行施工额
    @TableField(value="start_date")
    private Date startDate; // 合同开工日期
    @TableField(value="end_date")
    private Date endDate; // 合同竣工日期
    @TableField(value="quality_standard")
    private String qualityStandard; // 合同质量目标
    @TableField(value="safety_standard")
    private String safetyStandard; // 合同安全目标
    @TableField(value="xm_review_msg")
    private String xmReviewMsg; // 评审结论-项目部经理
    @TableField(value="sw_review_msg")
    private String swReviewMsg; // 评审结论-商务管理部
    @TableField(value="jz_review_msg")
    private String jzReviewMsg; // 评审结论-建造管理部
    @TableField(value="gc_review_msg")
    private String gcReviewMsg; // 评审结论-工程技术研究中心
    @TableField(value="aq_review_msg")
    private String aqReviewMsg; // 评审结论-安全生产监督管理部
    @TableField(value="cw_review_msg")
    private String cwReviewMsg; // 评审结论- 财务资金部
    @TableField(value="zh_review_msg")
    private String zhReviewMsg; // 评审结论- 综合办公室
    @TableField(value="fg_review_msg")
    private String fgReviewMsg; // 评审结论-分管领导审批
    @TableField(value="zjl_review_msg")
    private String zjlReviewMsg; // 评审结论-总经理
    @TableField(value="dsz_review_msg")
    private String dszReviewMsg; // 评审结论-董事长
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(exist = false)
    private String billStateName;

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public Long getBookId() {
        return bookId;
    }

    public void setBookId(Long bookId) {
        this.bookId = bookId;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public String getBuiltArea() {
        return builtArea;
    }

    public void setBuiltArea(String builtArea) {
        this.builtArea = builtArea;
    }
    public BigDecimal getZbContractMny() {
        return zbContractMny;
    }

    public void setZbContractMny(BigDecimal zbContractMny) {
        this.zbContractMny = zbContractMny;
    }
    public BigDecimal getZsContractMny() {
        return zsContractMny;
    }

    public void setZsContractMny(BigDecimal zsContractMny) {
        this.zsContractMny = zsContractMny;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }
    public String getQualityStandard() {
        return qualityStandard;
    }

    public void setQualityStandard(String qualityStandard) {
        this.qualityStandard = qualityStandard;
    }
    public String getSafetyStandard() {
        return safetyStandard;
    }

    public void setSafetyStandard(String safetyStandard) {
        this.safetyStandard = safetyStandard;
    }
    public String getXmReviewMsg() {
        return xmReviewMsg;
    }

    public void setXmReviewMsg(String xmReviewMsg) {
        this.xmReviewMsg = xmReviewMsg;
    }
    public String getSwReviewMsg() {
        return swReviewMsg;
    }

    public void setSwReviewMsg(String swReviewMsg) {
        this.swReviewMsg = swReviewMsg;
    }
    public String getJzReviewMsg() {
        return jzReviewMsg;
    }

    public void setJzReviewMsg(String jzReviewMsg) {
        this.jzReviewMsg = jzReviewMsg;
    }
    public String getGcReviewMsg() {
        return gcReviewMsg;
    }

    public void setGcReviewMsg(String gcReviewMsg) {
        this.gcReviewMsg = gcReviewMsg;
    }
    public String getAqReviewMsg() {
        return aqReviewMsg;
    }

    public void setAqReviewMsg(String aqReviewMsg) {
        this.aqReviewMsg = aqReviewMsg;
    }
    public String getCwReviewMsg() {
        return cwReviewMsg;
    }

    public void setCwReviewMsg(String cwReviewMsg) {
        this.cwReviewMsg = cwReviewMsg;
    }
    public String getZhReviewMsg() {
        return zhReviewMsg;
    }

    public void setZhReviewMsg(String zhReviewMsg) {
        this.zhReviewMsg = zhReviewMsg;
    }
    public String getFgReviewMsg() {
        return fgReviewMsg;
    }

    public void setFgReviewMsg(String fgReviewMsg) {
        this.fgReviewMsg = fgReviewMsg;
    }
    public String getZjlReviewMsg() {
        return zjlReviewMsg;
    }

    public void setZjlReviewMsg(String zjlReviewMsg) {
        this.zjlReviewMsg = zjlReviewMsg;
    }
    public String getDszReviewMsg() {
        return dszReviewMsg;
    }

    public void setDszReviewMsg(String dszReviewMsg) {
        this.dszReviewMsg = dszReviewMsg;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
